@@ -36,6 +36,8 @@ SEXP OGR_write(SEXP inp)
     char **papszCreateOptions = NULL;
     char **papszCreateOptionsLayer = NULL;
     SEXP ans, wkbtype_attr, comms;
+    int verbose = INTEGER_POINTER(getAttrib(VECTOR_ELT(inp, 5),
+        install("verbose")))[0];
     int pc=0, i, j, k;
 
     PROTECT(ans = NEW_CHARACTER(1)); pc++;
@@ -103,9 +105,16 @@ SEXP OGR_write(SEXP inp)
     const char *cl = CHAR(asChar(getAttrib(obj, R_ClassSymbol)));
     OGRwkbGeometryType wkbtype = wkbUnknown;
 
-    if (!strcmp(cl, "SpatialPointsDataFrame")) wkbtype = wkbPoint;
-    else if (!strcmp(cl, "SpatialLinesDataFrame"))  wkbtype = wkbLineString;
-    else if (!strcmp(cl, "SpatialPolygonsDataFrame")) wkbtype = wkbPolygon;
+    if (!strcmp(cl, "SpatialPointsDataFrame")) {
+        wkbtype = wkbPoint;
+        if (verbose) Rprintf("Object initially classed as: wkbPoint\n");
+    } else if (!strcmp(cl, "SpatialLinesDataFrame")) {
+        wkbtype = wkbLineString;
+        if (verbose) Rprintf("Object initially classed as: wkbLineString\n");
+    } else if (!strcmp(cl, "SpatialPolygonsDataFrame")) {
+        wkbtype = wkbPolygon;
+        if (verbose) Rprintf("Object initially classed as: wkbPolygon\n");
+    }
 
     SET_STRING_ELT(ans, 0, COPY_TO_USER_STRING(cl));
 
@@ -130,7 +139,10 @@ SEXP OGR_write(SEXP inp)
             Lns_l = length(GET_SLOT(VECTOR_ELT(lns, i), install("Lines")));
             if (Lns_l > 1) multi=1;
 	}
-        if (multi > 0) wkbtype = wkbMultiLineString;
+        if (multi > 0) {
+            wkbtype = wkbMultiLineString;
+            if (verbose) Rprintf("Object reclassed as: wkbMultiLineString\n");
+        }
     }
 
     if (wkbtype == wkbPolygon) {
@@ -145,7 +157,7 @@ SEXP OGR_write(SEXP inp)
             uninstallErrorHandlerAndTriggerError();
             error("number of objects mismatch");
         }
-        int multi=0, Pls_l;
+        int multi=0, Pls_l, icomms=0;
 	for (i=0; i<nobs; i++) {
             comms = SP_PREFIX(comment2comm)(VECTOR_ELT(pls, i));
             if (comms == R_NilValue) {
@@ -156,13 +168,21 @@ SEXP OGR_write(SEXP inp)
                     break;
                 }
             } else {
+                icomms = 1;
                 if (length(comms) > 1) {
                     multi=1;
                     break;
                 }
             }
 	}
-        if (multi > 0) wkbtype = wkbMultiPolygon;
+        if (verbose) {
+            if (icomms == 0) Rprintf("No SFS comments in Polygons objects\n");
+            else Rprintf("SFS comments in Polygons objects\n");
+        }
+        if (multi > 0) {
+            wkbtype = wkbMultiPolygon;
+            if (verbose) Rprintf("Object reclassed as: wkbMultiPolygon\n");
+        }
     }
 
 //  retrieve and set spatial reference system
@@ -297,6 +317,7 @@ SEXP OGR_write(SEXP inp)
             error("number of objects mismatch");
         }
 
+        if (verbose) Rprintf("Writing %d wkbPoint objects\n", nobs);
         installErrorHandler();
         for (i=0; i<nobs; i++) {
             OGRFeature *poFeature;
@@ -353,6 +374,7 @@ SEXP OGR_write(SEXP inp)
             error("number of objects mismatch");
         }
 
+        if (verbose) Rprintf("Writing %d wkbLineString objects\n", nobs);
         installErrorHandler();
 	for (i=0; i<nobs; i++) {
 
@@ -427,6 +449,7 @@ SEXP OGR_write(SEXP inp)
         }
         SEXP Lns;
         int Lns_l;
+        if (verbose) Rprintf("Writing %d wkbMultiLineString objects\n", nobs);
         installErrorHandler();
 	for (i=0; i<nobs; i++) {
 
@@ -519,7 +542,7 @@ SEXP OGR_write(SEXP inp)
             uninstallErrorHandlerAndTriggerError();
             error("number of objects mismatch");
         }
-
+        if (verbose) Rprintf("Writing %d wkbPolygon objects\n", nobs);
         installErrorHandler();
 	for (i=0; i<nobs; i++) {
 
@@ -532,7 +555,6 @@ SEXP OGR_write(SEXP inp)
             SEXP crds, dim;
 
             OGRPolygon OGRply;
-            OGRLinearRing OGRlr;
 
             comms = SP_PREFIX(comment2comm)(VECTOR_ELT(pls, i));
             if (comms == R_NilValue) {
@@ -540,6 +562,7 @@ SEXP OGR_write(SEXP inp)
                     install("Polygons")), 0), install("coords"));
                 dim = getAttrib(crds, install("dim"));
                 int ncrds = INTEGER_POINTER(dim)[0];
+                OGRLinearRing OGRlr;
                 for (j=0; j<ncrds; j++) 
                     OGRlr.setPoint( j, NUMERIC_POINTER(crds)[j],
                                    NUMERIC_POINTER(crds)[j+ncrds] );
@@ -551,6 +574,7 @@ SEXP OGR_write(SEXP inp)
                         0))[k]-R_OFFSET), install("coords"));
                     dim = getAttrib(crds, install("dim"));
                     int ncrds = INTEGER_POINTER(dim)[0];
+                    OGRLinearRing OGRlr;
                     for (j=0; j<ncrds; j++) 
                         OGRlr.setPoint( j, NUMERIC_POINTER(crds)[j],
                                    NUMERIC_POINTER(crds)[j+ncrds] );
@@ -614,12 +638,14 @@ SEXP OGR_write(SEXP inp)
         }
         SEXP Lns;
         int Lns_l;
+        if (verbose) Rprintf("Writing %d wkbMultiPolygon objects\n", nobs);
         installErrorHandler();
 	for (i=0; i<nobs; i++) {
             OGRFeature *poFeature;
             poFeature = new OGRFeature( poLayer->GetLayerDefn() );
             comms = SP_PREFIX(comment2comm)(VECTOR_ELT(pls, i));
             if (comms == R_NilValue) {
+
 // RSB 081009
                 Lns = GET_SLOT(VECTOR_ELT(pls, i), install("Polygons"));
                 Lns_l = (int) length(Lns);
